;; This is an operating system configuration generated
;; by the graphical installer.
;;
;; Once installation is complete, you can learn and modify
;; this file to tweak the system configuration, and pass it
;; to the 'guix system reconfigure' command to effect your
;; changes.


;; Indicate which modules to import to access the variables
;; used in this configuration.
(use-modules (gnu)
			 (nongnu packages linux)
			 (gnu packages shells)
			 (gnu packages cups))
(use-service-modules audio cups desktop networking ssh syncthing xorg)

(operating-system
 (kernel linux)
 (firmware (list linux-firmware))
 (locale "en_US.utf8")
 (timezone "America/Chicago")
 (keyboard-layout (keyboard-layout "us" "colemak"))
 (host-name "sanderson")
 (hosts-file (local-file "hosts"))
 ;; The list of user accounts ('root' is implicit).
 (users (cons* (user-account
                (name "skylar")
				(shell (file-append fish "/bin/fish"))
                (comment "Skylar")
                (group "users")
                (home-directory "/home/skylar")
                (supplementary-groups '("wheel" "netdev" "audio" "video"
										"lpadmin")))
			   %base-user-accounts))

 ;; Packages installed system-wide.  Users can also install packages
 ;; under their own account: use 'guix search KEYWORD' to search
 ;; for packages and 'guix install PACKAGE' to install a package.
 (packages (append (list (specification->package "nss-certs"))
				   %base-packages))

 ;; Below is the list of system services.  To search for available
 ;; services, run 'guix system search KEYWORD' in a terminal.
 (services
  (append (list

		   ;; To configure OpenSSH, pass an 'openssh-configuration'
		   ;; record as a second argument to 'service' below.
		   (service openssh-service-type)
		   (service tor-service-type)
		   (service cups-service-type
					(cups-configuration
					 (web-interface? #t)
					 (extensions
					  (list brlaser cups-filters epson-inkjet-printer-escpr
							foomatic-filters hplip splix))))
		   (service syncthing-service-type
					(syncthing-configuration
					 (user "skylar")
					 (home "/home/skylar"))))
		  
		  ;; This is the default list of services we
          ;; are appending to.
          (modify-services
		   %desktop-services
		   (delete gdm-service-type)
		   (guix-service-type config =>
							  (guix-configuration
							   (inherit config)
							   (substitute-urls
								(append
								 (list "https://substitutes.nonguix.org")
								 %default-substitute-urls))
							   (authorized-keys
								(append (list (local-file "./signing-key.pub"))
										%default-authorized-guix-keys)))))))
 (bootloader (bootloader-configuration
			  (bootloader grub-bootloader)
			  (targets (list "/dev/sda"))
			  (keyboard-layout keyboard-layout)))
 (swap-devices (list (swap-space
					  (target (uuid
							   "bbfae3a1-8471-4fa6-9cd5-d9c32059820d")))))

 ;; The list of file systems that get "mounted".  The unique
 ;; file system identifiers there ("UUIDs") can be obtained
 ;; by running 'blkid' in a terminal.

 (file-systems (cons* (file-system
					   (mount-point "/")
					   (device (uuid
                                "de8a0bfb-3a0c-4e53-8358-4bb31351bd7d"
                                'ext4))
					   (type "ext4")) %base-file-systems)))
